gatenlp.test_pydoc API documentation

# Module `gatenlp.test_pydoc`

Expand source code

    class TestPyDoc:

        @property
        def prop1(self):
            """
            Property that only has a getter.
            """
            return 1

        @property
        def prop2(self):
            """
            Property that has a getter and a setter.
            """
            return 2

        @prop2.setter
        def prop2(self, newval):
            """
            Property 2 setter method
            """
            pass

        @property
        def prop4(self):
            """
            Property 4 has a gett and deleter
            """
            return 4

        @prop4.deleter
        def prop4(self):
            """
            The Property 4 deleter
            """
            pass

        prop5 = property(None, lambda self, x: print(x), None, "Property 5 with a setter only")

## Classes

`class TestPyDoc`
  Expand source code

      class TestPyDoc:

          @property
          def prop1(self):
              """
              Property that only has a getter.
              """
              return 1

          @property
          def prop2(self):
              """
              Property that has a getter and a setter.
              """
              return 2

          @prop2.setter
          def prop2(self, newval):
              """
              Property 2 setter method
              """
              pass

          @property
          def prop4(self):
              """
              Property 4 has a gett and deleter
              """
              return 4

          @prop4.deleter
          def prop4(self):
              """
              The Property 4 deleter
              """
              pass

          prop5 = property(None, lambda self, x: print(x), None, "Property 5 with a setter only")

  ### Instance variables

  `property/get prop1`

    Property that only has a getter.

    Expand source code

        @property
        def prop1(self):
            """
            Property that only has a getter.
            """
            return 1

  `property/get/set prop2`

    Property that has a getter and a setter.

    Expand source code

        @property
        def prop2(self):
            """
            Property that has a getter and a setter.
            """
            return 2

  `property/get/del prop4`

    Property 4 has a gett and deleter

    Expand source code

        @property
        def prop4(self):
            """
            Property 4 has a gett and deleter
            """
            return 4

  `property/set prop5`

    Property 5 with a setter only